@@ -266,7 +266,7 @@ def preprocess(
     -----------------
     Return x, y
     """
-    rows = len(df)
+    # rows = len(df)
     df['Volume'] = df['Volume'].astype(float)
     x = df.drop(target_col, axis=1) if target_col is not None else df
     x = x[continous_cols]
@@ -276,11 +276,15 @@ def preprocess(
     if continous_cols:
         x[continous_cols] = x[continous_cols] #.pct_change().dropna()
     idx = x.index
-    x = x.select_dtypes(include=[int, float]).dropna().to_numpy()
+
+    """MIGHT NEED TO REPLACE DROPNA WITH IMPUTAITON???"""
+    x = x.select_dtypes(include=[int, float]).fillna(method='ffill').to_numpy()
     
     if target_col is not None:
-        y = df[target_col].dropna()
-        y = y.to_numpy().reshape(rows, target_dim)
+        y = df[target_col].fillna(mothod='ffill')
+        
+        y = y.to_numpy().reshape(len(y), target_dim)
+        
         if return_idx:
             return x, y, idx
         return x, y
